The other variables from the original bfi dataset were skipped and the categories are 'downcoded' to '0,1,2,3,4,5' to have a simple, ready to use example data frame. For further Information on the original dataset see R-package {psych}.
The category meanings (after downcoding) are as follows:
score 0Very Inaccurate
score 1Moderately Inaccurate
score 2Slightly Inaccurate
score 3Slightly Accurate
score 4Moderately Accurate
score 5Very Accurate
The Item meanings are as follows:
N1Get angry easily.
N2Get irritated easily.
N3Have frequent mood swings.
N4Often feel blue.
N5Panic easily.
The covariates like gender, education and age are in a seperate dataset cov_bfi