Parameter calculation is based on the construction of a
paired comparison matrix Mnij with entries
fij representing the number of respondents who got
item i right and item j wrong according to
Choppin's (1968, 1985) conditional pairwise algorithm.
This algorithm is simply realized by matrix
multiplication. To avoid numerical problems with off diagonal zero's when
constructing the pairwise comparison matrix Mnij,
powers of the Mnij matrix, can be used (Choppin,
1968, 1985). Using powers k of Mnij
replaces the results of the direct comparisons between
i and j with the sum of the indirect
comparisons of i and j through an
intermediate k.
In general, it is recommended to use the argument with
default value pot=TRUE.